﻿Param (
    [string]$PRTGBaseURL,
    [string]$PRTGToken
)


add-type @"
    using System.Net;
    using System.Security.Cryptography.X509Certificates;
    public class TrustAllCertsPolicy : ICertificatePolicy {
        public bool CheckValidationResult(
            ServicePoint srvPoint, X509Certificate certificate,
            WebRequest request, int certificateProblem) {
            return true;
        }
    }
"@
[System.Net.ServicePointManager]::CertificatePolicy = New-Object TrustAllCertsPolicy
[System.Net.ServicePointManager]::SecurityProtocol = [Net.SecurityProtocolType]::Tls12

0..4 | %{
    $statistics = @()
    $texts = $()
    $daServers = (Get-RemoteAccessLoadBalancer).nlbNodeStatus
    $allNodesStatusCode = 1
    $prtg = '' | select prtg
    $prtg.prtg = '' | select result

    $results = @()

    foreach ($daserver in $daservers) {
        if ($daserver.statusCode -eq 'Reachable') {
            $server = $daserver.hostname.Split('.')[0]
            $statistic = Get-RemoteAccessConnectionStatisticsSummary -computername $daserver.hostname
            $statistics += $statistic
            $results += @{
                Channel = 'Connections {0}' -f $server
                Value = $statistic.totaldaconnections
                }
            $results += @{
                Channel = 'MaxConnections {0}' -f $server
                Value = $statistic.MaxConcurrentConnections
                }
            $results += @{
                Channel = 'CumulativeConnections {0}' -f $server
                Value = $statistic.totalCumulativeConnections
                Mode = 'Difference'
                }
            $results += @{
                Channel = 'BytesIN {0}' -f $server
                Value = $statistic.totalBytesIN
                Unit = 'BytesFile'
                Mode = 'Difference'
                }
            $results += @{
                Channel = 'BytesOUT {0}' -f $server
                Value = $statistic.totalBytesOUT
                Unit = 'BytesFile'
                Mode = 'Difference'
                }
        } else {
            $allNodesStatusCode = 0
            $texts += 'Node {0} seems to be not reachable at the moment ({1})! Please check Clusterstatus manually!' -f $daserver.hostname, $daserver.statusCode
        }
    }
    $results += @{
        Channel = 'Status'
        Value = $allNodesStatusCode
        ValueLookup = 'prtg.standardlookups.boolean.statetrueok'
        }

    $results += @{
        Channel = 'Connections Total'
        Value = ($statistics.totaldaconnections | Measure-Object -sum).sum
        }
    $results += @{
        Channel = 'MaxConnections Total'
        Value = ($statistics.MaxConcurrentConnections | Measure-Object -sum).sum
        }
    $results += @{
        Channel = 'CumulativeConnections Total'
        Value = ($statistics.totalCumulativeConnections | Measure-Object -sum).sum
        Mode = 'Difference'
        }
    $results += @{
        Channel = 'BytesIN Total'
        Value = ($statistics.totalBytesIN | Measure-Object -sum).sum
        Unit = 'BytesFile'
        Mode = 'Difference'
        }
    $results += @{
        Channel = 'BytesOUT Total'
        Value = ($statistics.totalBytesOUT | Measure-Object -sum).sum
        Unit = 'BytesFile'
        Mode = 'Difference'
        }
    if ($text -or ($texts.count -gt 0)) {
        $prtg.prtg | Add-Member -MemberType NoteProperty -Name 'text' -Value $null
        $prtg.prtg.text = @($text, ($texts -join '; ')) -join '; '
    }

    $prtg.prtg.result = $results
    $prtgJson = $prtg | ConvertTo-Json -Depth 5

    Invoke-RestMethod -Uri ("$PRTGBaseURL/$PRTGToken/?content={0}" -f $prtgJson) -Method Post
    if ($_ -lt 4) {
        sleep 60
    }
}